@@ -177,6 +177,7 @@ class HolmesWorker(BaseWorker):
                     err = str(sys.exc_info()[1])
                     self.error("Fail to review %s: %s" % (job['url'], err))
                     self.db.rollback()
+                    raise
 
                 lock = job.get('lock', None)
                 self._complete_job(lock, error=err)
@@ -190,6 +191,7 @@ class HolmesWorker(BaseWorker):
             err = str(sys.exc_info()[1])
             self.error("Fail to complete work: %s" % err)
             self.db.rollback()
+            raise
 
     def _start_reviewer(self, job):
         if job:
@@ -268,6 +270,7 @@ class HolmesWorker(BaseWorker):
         self.working_url = None
         self.domain_name = None
         self._ping_api()
+        self.cache.release_next_job(lock)
 
     def _update_pages_score(self):
         expiration = self.config.UPDATE_PAGES_SCORE_EXPIRATION
